==> sqlitestudio-3.0.7.tar.gz: Plugins/HtmlExport/HtmlExport_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>HtmlExport</name>
    <message>
        <location filename="htmlexport.cpp" line="46"/>
        <source>SQL query results</source>
        <translation>Résultats de la requête SQL</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="78"/>
        <location filename="htmlexport.cpp" line="155"/>
        <source>no type</source>
        <translation>Aucun type</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="115"/>
        <location filename="htmlexport.cpp" line="243"/>
        <source>Exported table: %1</source>
        <translation>Table exportée: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="127"/>
        <location filename="htmlexport.cpp" line="255"/>
        <source>Table: %1</source>
        <translation>Table: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="255"/>
        <source>virtual</source>
        <translation>virtuel</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="308"/>
        <source>Exported database: %1</source>
        <translation>Base de données exportée: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="324"/>
        <source>Index: %1</source>
        <translation>Index: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="330"/>
        <source>For table:</source>
        <translation>Pour la table: </translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="337"/>
        <source>Unique:</source>
        <translation>Unique:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="338"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="338"/>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="344"/>
        <source>Column</source>
        <translation>Colonne</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="345"/>
        <source>Collating</source>
        <translation>Collation</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="346"/>
        <source>Sort order</source>
        <translation>Ordre de tri</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="377"/>
        <source>Trigger: %1</source>
        <translation>Déclencheur: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="383"/>
        <source>Activated:</source>
        <translation>Activé:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="391"/>
        <source>Action:</source>
        <translation>Action:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="398"/>
        <source>On view:</source>
        <translation>Sur la vue:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="400"/>
        <source>On table:</source>
        <translation>Sur la table:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="411"/>
        <source>Activate condition:</source>
        <translation>Activé la condition:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="418"/>
        <source>Code executed:</source>
        <translation>Exécuter le code:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="452"/>
        <source>View: %1</source>
        <translation>Vue: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="477"/>
        <source>Document generated by SQLiteStudio v%1 on %2</source>
        <translation>Document généré par SQLiteStudio v%1 de %2</translation>
    </message>
</context>
<context>
    <name>HtmlExportConfig</name>
    <message>
        <location filename="htmlexport.ui" line="36"/>
        <source>Maximum number of characters per cell:</source>
        <translation>Nombre de caractères maximum par cellule:</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="43"/>
        <source>Include data types in first row</source>
        <translation>Types données incluses dans la première ligne</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="53"/>
        <source>Column names as first row</source>
        <translation>Nom des colonnes dans la première ligne</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="63"/>
        <source>Row numbers as first column</source>
        <translation>Numero de ligne dans la première colonne</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="73"/>
        <source>Output format</source>
        <translation>Format d&apos;affichage</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="79"/>
        <source>Format document (new lines, indentation)</source>
        <translation>Format document (nouvelles ligne, indentation)</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="92"/>
        <source>Compress (everything in one line)</source>
        <translation>Condensé (tout en une ligne)</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="108"/>
        <source>&lt;p&gt;When enabled, HTML characters such as &amp;lt;, &amp;gt; and &amp;amp; are not escaped in exported values. This allows you for example to export hyper-link enabled documents, but it also may result in incorrect HTML document (unmatched pairs of &amp;lt; and &amp;gt; characters). Be warned.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Lorsqu&apos;il y a des caractères HTML telque &amp;lt;, &amp;gt; et &amp;amp;ils ne sont pas enlevés des valeurs exportées. This allows you for example to export hyper-link enabled documents, but it also may result in incorrect HTML document (unmatched pairs of &amp;lt; and &amp;gt; characters).Soyez attentif.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="111"/>
        <source>Don&apos;t escape HTML characters</source>
        <translation>N&apos;enlevez pas les caractères HTML</translation>
    </message>
</context>
</TS>

==> sqlitestudio_3.1.0.orig.tar.gz: Plugins/HtmlExport/HtmlExport_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>HtmlExport</name>
    <message>
        <location filename="htmlexport.cpp" line="46"/>
        <source>SQL query results</source>
        <translation>Résultats de la requête SQL</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="78"/>
        <location filename="htmlexport.cpp" line="155"/>
        <source>no type</source>
        <translation>Aucun type</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="115"/>
        <location filename="htmlexport.cpp" line="243"/>
        <source>Exported table: %1</source>
        <translation>Table exportée: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="127"/>
        <location filename="htmlexport.cpp" line="255"/>
        <source>Table: %1</source>
        <translation>Table: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="255"/>
        <source>virtual</source>
        <translation>virtuel</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="308"/>
        <source>Exported database: %1</source>
        <translation>Base de données exportée: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="324"/>
        <source>Index: %1</source>
        <translation>Index: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="330"/>
        <source>For table:</source>
        <translation>Pour la table: </translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="337"/>
        <source>Unique:</source>
        <translation>Unique:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="338"/>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="338"/>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="344"/>
        <source>Column</source>
        <translation>Colonne</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="345"/>
        <source>Collating</source>
        <translation>Collation</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="346"/>
        <source>Sort order</source>
        <translation>Ordre de tri</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="377"/>
        <source>Trigger: %1</source>
        <translation>Déclencheur: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="383"/>
        <source>Activated:</source>
        <translation>Activé:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="391"/>
        <source>Action:</source>
        <translation>Action:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="398"/>
        <source>On view:</source>
        <translation>Sur la vue:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="400"/>
        <source>On table:</source>
        <translation>Sur la table:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="411"/>
        <source>Activate condition:</source>
        <translation>Activé la condition:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="418"/>
        <source>Code executed:</source>
        <translation>Exécuter le code:</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="452"/>
        <source>View: %1</source>
        <translation>Vue: %1</translation>
    </message>
    <message>
        <location filename="htmlexport.cpp" line="477"/>
        <source>Document generated by SQLiteStudio v%1 on %2</source>
        <translation>Document généré par SQLiteStudio v%1 de %2</translation>
    </message>
</context>
<context>
    <name>HtmlExportConfig</name>
    <message>
        <location filename="htmlexport.ui" line="36"/>
        <source>Maximum number of characters per cell:</source>
        <translation>Nombre de caractères maximum par cellule:</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="43"/>
        <source>Include data types in first row</source>
        <translation>Types données incluses dans la première ligne</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="53"/>
        <source>Column names as first row</source>
        <translation>Nom des colonnes dans la première ligne</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="63"/>
        <source>Row numbers as first column</source>
        <translation>Numero de ligne dans la première colonne</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="73"/>
        <source>Output format</source>
        <translation>Format d&rsquo;affichage</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="79"/>
        <source>Format document (new lines, indentation)</source>
        <translation>Format document (nouvelles ligne, indentation)</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="92"/>
        <source>Compress (everything in one line)</source>
        <translation>Condensé (tout en une ligne)</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="108"/>
        <source>&lt;p&gt;When enabled, HTML characters such as &amp;lt;, &amp;gt; and &amp;amp; are not escaped in exported values. This allows you for example to export hyper-link enabled documents, but it also may result in incorrect HTML document (unmatched pairs of &amp;lt; and &amp;gt; characters). Be warned.&lt;/p&gt;</source>
        <translation>&lt;p&gt;Lorsqu&rsquo;il y a des caractères HTML telque &amp;lt;, &amp;gt; et &amp;amp;ils ne sont pas enlevés des valeurs exportées. This allows you for example to export hyper-link enabled documents, but it also may result in incorrect HTML document (unmatched pairs of &amp;lt; and &amp;gt; characters).Soyez attentif.&lt;/p&gt;</translation>
    </message>
    <message>
        <location filename="htmlexport.ui" line="111"/>
        <source>Don&apos;t escape HTML characters</source>
        <translation>N&rsquo;enlevez pas les caractères HTML</translation>
    </message>
</context>
</TS>
